
From: Oleg Nesterov <oleg@tv-sign.ru>

This patch moves some code into the get_next_ra_size() and renames it into
'set_next_ahead_window'.

Signed-off-by: Oleg Nesterov <oleg@tv-sign.ru>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/mm/readahead.c |   31 ++++++++++++++-----------------
 1 files changed, 14 insertions(+), 17 deletions(-)

diff -puN mm/readahead.c~cleanup-ahead-window-calculation mm/readahead.c
--- 25/mm/readahead.c~cleanup-ahead-window-calculation	2005-01-25 18:40:10.394671928 -0800
+++ 25-akpm/mm/readahead.c	2005-01-25 18:41:50.338478160 -0800
@@ -85,20 +85,23 @@ static unsigned long get_init_ra_size(un
  * not for each call to readahead.  If a cache miss occured, reduce next I/O
  * size, else increase depending on how close to max we are.
  */
-static unsigned long get_next_ra_size(unsigned long cur, unsigned long max,
-				unsigned long min, unsigned long * flags)
+static void set_next_ahead_window(struct file_ra_state *ra,
+				unsigned long max, unsigned long min)
 {
 	unsigned long newsize;
+	unsigned long cur = ra->size;
 
-	if (*flags & RA_FLAG_MISS) {
+	ra->ahead_start = ra->start + cur;
+
+	if (ra->flags & RA_FLAG_MISS) {
+		ra->flags &= ~RA_FLAG_MISS;
 		newsize = max((cur - 2), min);
-		*flags &= ~RA_FLAG_MISS;
-	} else if (cur < max / 16) {
+	} else if (cur < max / 16)
 		newsize = 4 * cur;
-	} else {
+	else
 		newsize = 2 * cur;
-	}
-	return min(newsize, max);
+
+	ra->ahead_size = min(newsize, max);
 }
 
 #define list_to_page(head) (list_entry((head)->prev, struct page, lru))
@@ -457,9 +460,7 @@ page_cache_readahead(struct address_spac
 		 * immediately.
 		 */
 		if (req_size >= max) {
-			ra->ahead_size = get_next_ra_size(ra->size, max, min,
-							  &ra->flags);
-			ra->ahead_start = ra->start + ra->size;
+			set_next_ahead_window(ra, max, min);
 			blockable_page_cache_readahead(mapping, filp,
 				 ra->ahead_start, ra->ahead_size, ra, 1);
 		}
@@ -484,9 +485,7 @@ page_cache_readahead(struct address_spac
 	 */
 
 	if (ra->ahead_start == 0) {	 /* no ahead window yet */
-		ra->ahead_size = get_next_ra_size(ra->size, max, min,
-						  &ra->flags);
-		ra->ahead_start = ra->start + ra->size;
+		set_next_ahead_window(ra, max, min);
 		block = ((offset + newsize -1) >= ra->ahead_start);
 		if (!blockable_page_cache_readahead(mapping, filp,
 		    ra->ahead_start, ra->ahead_size, ra, block)) {
@@ -517,9 +516,7 @@ page_cache_readahead(struct address_spac
 	if ((offset + newsize - 1) >= ra->ahead_start) {
 		ra->start = ra->ahead_start;
 		ra->size = ra->ahead_size;
-		ra->ahead_start = ra->ahead_start + ra->ahead_size;
-		ra->ahead_size = get_next_ra_size(ra->ahead_size,
-						  max, min, &ra->flags);
+		set_next_ahead_window(ra, max, min);
 		block = ((offset + newsize - 1) >= ra->ahead_start);
 		if (!blockable_page_cache_readahead(mapping, filp,
 			ra->ahead_start, ra->ahead_size, ra, block)) {
_
